@@ -75,7 +75,7 @@ class PubSub:
         ]
         if self.gcp_credentials_json:
             credentials = service_account.Credentials.from_service_account_info(self.gcp_credentials_json, scopes=scopes)
-        if self.gcp_credentials_file:
+        elif self.gcp_credentials_file:
             credentials = service_account.Credentials.from_service_account_file(self.gcp_credentials_file, scopes=scopes)
         else:
             credentials, _ = google.auth.default(scopes=scopes)
@@ -205,7 +205,11 @@ class PubSub:
                     exec_time = time.time()
                     print(f'status=received message_id={message.message.message_id} function={funcref}')
                     try:
-                        result = request['callback'](*args, **kwargs)
+                        if self.flask:
+                            with self.flask.app_context():
+                                result = request['callback'](*args, **kwargs)
+                        else:
+                            result = request['callback'](*args, **kwargs)
                     except Exception:
                         result = 'crash'
                         traceback.print_exc()
